High-quality version of the CELEBA dataset, consisting of 30000 images in 1024 x
1024 resolution.

Note: CelebAHQ dataset may contain potential bias. The fairness indicators
[example](https://www.tensorflow.org/responsible_ai/fairness_indicators/tutorials/Fairness_Indicators_TFCO_CelebA_Case_Study)
goes into detail about several considerations to keep in mind while using the
CelebAHQ dataset.

WARNING: This dataset currently requires you to prepare images on your own.
